@@ -1,6 +1,6 @@
 package List::Objects::WithUtils::Role::Hash;
 {
-  $List::Objects::WithUtils::Role::Hash::VERSION = '1.001001';
+  $List::Objects::WithUtils::Role::Hash::VERSION = '1.002000';
 }
 use strictures 1;
 
@@ -18,6 +18,10 @@ sub array_type { 'List::Objects::WithUtils::Array' }
 
 sub clear { %{ $_[0] } = () }
 
+sub copy {
+  bless +{ %{ $_[0] } }, blessed($_[0])
+}
+
 sub defined { CORE::defined $_[0]->{ $_[1] } }
 sub exists  { CORE::exists  $_[0]->{ $_[1] } }
 
@@ -155,6 +159,10 @@ will be returned:
 
 Clears the current hash entirely.
 
+=head2 copy
+
+Creates a shallow clone of the current object.
+
 =head2 is_empty
 
 Returns boolean true if the hash has no keys.
@@ -165,6 +173,14 @@ Returns boolean true if the hash has no keys.
 
 Returns boolean true if the key has a defined value.
 
+=head2 delete
+
+  $hash->delete( @keys );
+
+Deletes keys from the hash.
+
+Returns an L</array_type> object containing the deleted values.
+
 =head2 exists
 
   if ( $hash->exists($key) ) { ... }
@@ -182,14 +198,6 @@ If we're taking a slice (multiple keys were specified), values are returned
 as an L</array_type> object. (See L</sliced> if you'd rather generate a new
 hash.)
 
-=head2 sliced
-
-  my $newhash = $hash->slice(@keys);
-
-Returns a new hash object built from the specified set of keys.
-
-(See L</get> if you only need the values.)
-
 =head2 keys
 
   my @keys = $hash->keys->all;
@@ -222,13 +230,13 @@ Sets keys in the hash.
 
 Returns an L</array_type> object containing the new values.
 
-=head2 delete
+=head2 sliced
 
-  $hash->delete( @keys );
+  my $newhash = $hash->slice(@keys);
 
-Deletes keys from the hash.
+Returns a new hash object built from the specified set of keys.
 
-Returns an L</array_type> object containing the deleted values.
+(See L</get> if you only need the values.)
 
 =head1 SEE ALSO
 
